@@ -7,7 +7,7 @@ use Clone::PP();
 use Rose::Object;
 our @ISA = qw(Rose::Object);
 
-our $VERSION = '0.728';
+our $VERSION = '0.729';
 
 our $Debug = 0;
 
@@ -20,7 +20,8 @@ use Rose::Object::MakeMethods::Generic
   'scalar' =>
   [
     qw(database domain dsn dbi_driver host password port
-       server_time_zone schema catalog type username)
+       server_time_zone schema catalog type username
+       description)
   ],
 
   'boolean' =>
@@ -63,8 +64,8 @@ sub dump
   my %dump;
 
   foreach my $attr (qw(database dsn driver host password port
-                       server_time_zone schema catalog type username
-                       connect_options pre_disconnect_sql 
+                       description server_time_zone schema catalog 
+                       type username connect_options pre_disconnect_sql 
                        post_connect_sql))
   {
     my $value = $self->$attr();
@@ -80,10 +81,12 @@ sub dump
     next  unless(defined $value);
     $dump{$attr} = Clone::PP::clone($value);
   }
-  
+
   return \%dump;
 }
 
+sub clone { Clone::PP::clone($_[0]) }
+
 1;
 
 __END__
@@ -142,6 +145,10 @@ Get or set the value of the "AutoCommit" connect option.
 
 Get or set the database catalog name.  This setting is only relevant to databases that support the concept of catalogs.
 
+=item B<clone>
+
+Returns a clone (i.e., deep copy) of the current object.
+
 =item B<connect_option NAME [, VALUE]>
 
 Get or set the connect option named NAME.  Returns the current value of the connect option.
@@ -158,6 +165,10 @@ Returns a reference to the hash of options in scalar context, or a list of name/
 
 Get or set the database name.
 
+=item B<description [TEXT]>
+
+A description of the data source.
+
 =item B<domain [DOMAIN]>
 
 Get or set the data source domain.  Note that changing the C<domain> after a registry entry has been added to the registry has no affect on where the entry appears in the registry.
